<?php
if ( !defined( 'IN_CMS' ) ) {
    exit();
}

use \IoC;
use \Configuration;
use models\Template;
use models\Permission;
use plugins\blog\models\Post;

$schema = IoC::resolve( 'sqlschema' );

$schema->dropIndex( 'UX_blog_post', 'blog_post' );

$schema->dropForeignKey( 'FK_blog_post', 'blog_post' );

$schema->dropForeignKey( 'FK_blog_comment', 'blog_comment' );

$schema->dropTable( 'blog_comment' );

$schema->dropTable( 'blog_post' );

$database = IoC::resolve( 'database' );
$tags = array_unique( array_column( $database->select( 'tag', ['[<>]tagging' => 'tag_id'], ['tag_id'], ['taggable_type' => Post::getTableName()] ), 'tag_id' ) );
foreach( $tags as $tagId ) {
    $database->delete( 'tag', ['tag_id' => $tagId] );
}

$permission = Permission::findOne( ['name' => 'blog.view_blog_posts'] );
$permission->delete();
$permission = Permission::findOne( ['name' => 'blog.create_blog_post'] );
$permission->delete();
$permission = Permission::findOne( ['name' => 'blog.update_blog_post'] );
$permission->delete();
$permission = Permission::findOne( ['name' => 'blog.delete_blog_post'] );
$permission->delete();
$permission = Permission::findOne( ['name' => 'blog.moderate_comments'] );
$permission->delete();

$configurationHandler = IoC::resolve( 'databaseConfigurationHandler' );
$settings = new Configuration( $configurationHandler );

$template = Template::findOne( $settings['blog.sidebar'] );
if ( isset( $template ) ) {
    $template->delete();
}

$template = Template::findOne( $settings['blog.post_template'] );
if ( isset( $template ) ) {
    $template->delete();
}

$template = Template::findOne( $settings['blog.index_template'] );
if ( isset( $template ) ) {
    $template->delete();
}

unset( $settings['blog.sidebar'] );
unset( $settings['blog.post_template'] );
unset( $settings['blog.index_template'] );
unset( $settings['blog.posts_per_page'] );
unset( $settings['blog.moderate_comments'] );
unset( $settings['blog.spam_keywords'] );

$configurationHandler->save();

$logger = IoC::resolve( 'logger' );
$logger->info( 'Plugin blog successfully uninstalled.' );

return true;
